==> zzyj-outputvalcount-impl-3.0.0-20230616.073044-189-sources.jar: com/ejianc/business/appliances/bean/MeteringRegisterEntity.java <==
package com.ejianc.business.appliances.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.appliances.bean.MeteringRegisterDetailEntity;
/**
 * 器具-计量器具登记
 * 
 * @author generator
 * 
 */
 @TableName("t_appliances_metering_register")
public class MeteringRegisterEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="operator_id")
    private Long operatorId; // 经办人ID
    @TableField(value="operator_name")
    private String operatorName; // 经办人姓名
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="patrol_group_id")
    private Long patrolGroupId; // 所属巡检组id
    @TableField(value="patrol_group")
    private String patrolGroup; // 所属巡检组：1、巡检一组 2、巡检二组 3、巡检三组
    @TableField(value="project_id")
    private Long projectId; // 工程名称id
    @TableField(value="project_name")
    private String projectName; // 工程名称
    @TableField(value="technology_id")
    private Long technologyId; // 项目技术负责人
    @TableField(value="technology_name")
    private String technologyName; // 项目技术负责人名称
    @TableField(value="engineering_type_id")
    private Long engineeringTypeId; // 工程类别
    @TableField(value="engineering_type")
    private String engineeringType; // 工程类型名称
    @TableField(value="testers_id")
    private Long testersId; // 试验员
    @TableField(value="testers_name")
    private String testersName; // 试验员名称
    @TableField(value="start_date")
    private Date startDate; // 进场日期
    @TableField(value="structure_type")
    private Long structureType; // 结构类型
    @TableField(value="structure_type_name")
    private String structureTypeName; // 结构类型名称
    
    
    @TableField(exist=false)
    @SubEntity(serviceName="meteringRegisterDetailService", pidName = "registerId")
    private List<MeteringRegisterDetailEntity> meteringRegisterDetailList = new ArrayList<>(); // 器具-计量器具登记详情
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public Long getPatrolGroupId() {
        return patrolGroupId;
    }

    public void setPatrolGroupId(Long patrolGroupId) {
        this.patrolGroupId = patrolGroupId;
    }
    public String getPatrolGroup() {
        return patrolGroup;
    }

    public void setPatrolGroup(String patrolGroup) {
        this.patrolGroup = patrolGroup;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getTechnologyId() {
        return technologyId;
    }

    public void setTechnologyId(Long technologyId) {
        this.technologyId = technologyId;
    }
    public String getTechnologyName() {
        return technologyName;
    }

    public void setTechnologyName(String technologyName) {
        this.technologyName = technologyName;
    }
    public Long getEngineeringTypeId() {
        return engineeringTypeId;
    }

    public void setEngineeringTypeId(Long engineeringTypeId) {
        this.engineeringTypeId = engineeringTypeId;
    }
    public String getEngineeringType() {
        return engineeringType;
    }

    public void setEngineeringType(String engineeringType) {
        this.engineeringType = engineeringType;
    }
    public Long getTestersId() {
        return testersId;
    }

    public void setTestersId(Long testersId) {
        this.testersId = testersId;
    }
    public String getTestersName() {
        return testersName;
    }

    public void setTestersName(String testersName) {
        this.testersName = testersName;
    }

    public Date getStartDate() {
        return startDate;
    }

    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }

    public Long getStructureType() {
        return structureType;
    }

    public void setStructureType(Long structureType) {
        this.structureType = structureType;
    }
    public String getStructureTypeName() {
        return structureTypeName;
    }

    public void setStructureTypeName(String structureTypeName) {
        this.structureTypeName = structureTypeName;
    }
    

    public List<MeteringRegisterDetailEntity> getMeteringRegisterDetailList() {
        return meteringRegisterDetailList;
    }

    public void setMeteringRegisterDetailList(List<MeteringRegisterDetailEntity> meteringRegisterDetailList) {
        this.meteringRegisterDetailList = meteringRegisterDetailList;
    }
}

==> zzyj-outputvalcount-impl-3.0.0-20230815.001915-230-sources.jar: com/ejianc/business/appliances/bean/MeteringRegisterEntity.java <==
package com.ejianc.business.appliances.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.appliances.bean.MeteringRegisterDetailEntity;
/**
 * 器具-计量器具登记
 * 
 * @author generator
 * 
 */
 @TableName("t_appliances_metering_register")
public class MeteringRegisterEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="operator_id")
    private Long operatorId; // 经办人ID
    @TableField(value="operator_name")
    private String operatorName; // 经办人姓名
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="patrol_group_id")
    private Long patrolGroupId; // 所属巡检组id
    @TableField(value="patrol_group")
    private String patrolGroup; // 所属巡检组：1、巡检一组 2、巡检二组 3、巡检三组
    @TableField(value="project_id")
    private Long projectId; // 工程名称id
    @TableField(value="project_name")
    private String projectName; // 工程名称
    @TableField(value="technology_id")
    private Long technologyId; // 项目技术负责人
    @TableField(value="technology_name")
    private String technologyName; // 项目技术负责人名称
    @TableField(value="engineering_type_id")
    private Long engineeringTypeId; // 工程类别
    @TableField(value="engineering_type")
    private String engineeringType; // 工程类型名称
    @TableField(value="testers_id")
    private Long testersId; // 试验员
    @TableField(value="testers_name")
    private String testersName; // 试验员名称
    @TableField(value="start_date")
    private Date startDate; // 进场日期
    @TableField(value="structure_type")
    private Long structureType; // 结构类型
    @TableField(value="structure_type_name")
    private String structureTypeName; // 结构类型名称
    @TableField(value = "work_date")
    private Date workDate;//开工日期


    @TableField(exist=false)
    @SubEntity(serviceName="meteringRegisterDetailService", pidName = "registerId")
    private List<MeteringRegisterDetailEntity> meteringRegisterDetailList = new ArrayList<>(); // 器具-计量器具登记详情
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public Long getPatrolGroupId() {
        return patrolGroupId;
    }

    public void setPatrolGroupId(Long patrolGroupId) {
        this.patrolGroupId = patrolGroupId;
    }
    public String getPatrolGroup() {
        return patrolGroup;
    }

    public void setPatrolGroup(String patrolGroup) {
        this.patrolGroup = patrolGroup;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getTechnologyId() {
        return technologyId;
    }

    public void setTechnologyId(Long technologyId) {
        this.technologyId = technologyId;
    }
    public String getTechnologyName() {
        return technologyName;
    }

    public void setTechnologyName(String technologyName) {
        this.technologyName = technologyName;
    }
    public Long getEngineeringTypeId() {
        return engineeringTypeId;
    }

    public void setEngineeringTypeId(Long engineeringTypeId) {
        this.engineeringTypeId = engineeringTypeId;
    }
    public String getEngineeringType() {
        return engineeringType;
    }

    public void setEngineeringType(String engineeringType) {
        this.engineeringType = engineeringType;
    }
    public Long getTestersId() {
        return testersId;
    }

    public void setTestersId(Long testersId) {
        this.testersId = testersId;
    }
    public String getTestersName() {
        return testersName;
    }

    public void setTestersName(String testersName) {
        this.testersName = testersName;
    }

    public Date getStartDate() {
        return startDate;
    }

    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }

    public Long getStructureType() {
        return structureType;
    }

    public void setStructureType(Long structureType) {
        this.structureType = structureType;
    }
    public String getStructureTypeName() {
        return structureTypeName;
    }

    public void setStructureTypeName(String structureTypeName) {
        this.structureTypeName = structureTypeName;
    }
    

    public List<MeteringRegisterDetailEntity> getMeteringRegisterDetailList() {
        return meteringRegisterDetailList;
    }

    public void setMeteringRegisterDetailList(List<MeteringRegisterDetailEntity> meteringRegisterDetailList) {
        this.meteringRegisterDetailList = meteringRegisterDetailList;
    }

    public Date getWorkDate() {
        return workDate;
    }

    public void setWorkDate(Date workDate) {
        this.workDate = workDate;
    }
}
